.. Copyright 2022, 2023 Reahl Software Services (Pty) Ltd. All rights reserved.


Configuring your component via setup.cfg
========================================


Since Reahl 7.0.0 a component is :doc:`defined in the `pyproject.toml`file <pyproject.toml>` instead.

